@@ -1,6 +1,10 @@
 import typing as t
-from .base import Action, action
-from .procs import weather, youdao, browser, memegen, fileoperation
+from urge import procs
+
+# from .base import Action, action
+# from .procs import weather, youdao, browser, memegen, fileoperation
+from urge.base import Action, action
+from urge.procs import weather, youdao, browser, memegen, fileoperation
 from dataclasses import dataclass
 
 
@@ -46,7 +50,7 @@ class get_simple_temp(Action):
 class translate(Action):
     q: str
     full: bool = False
-    procs = [youdao.translate_post, youdao.translate_filter]
+    procs = [youdao.trans_post, youdao.trans_filter]
 
 
 @dataclass
@@ -61,6 +65,30 @@ class easy_ocr(Action):
     procs = [youdao.pic2base64, youdao.ocr_post, youdao.ocr_ret]
 
 
+@dataclass
+class pic_translate(Action):
+    path: str
+    procs = [youdao.pic2base64, youdao.pictrans_post, youdao.pictrans_write]
+
+
+@dataclass
+class handwrite_ocr(Action):
+    path: str
+    procs = [youdao.pic2base64, youdao.ocr_post, youdao.ocr_ret]
+
+
+@dataclass
+class receipt_ocr(Action):
+    path: str
+    procs = [youdao.pic2base64, youdao.receipt_ocr_post, youdao.receipt_ocr_ret]
+
+
+@dataclass
+class table_ocr(Action):
+    path: str
+    procs = [youdao.pic2base64, youdao.table_ocr_post, youdao.table_write_excel]
+
+
 @dataclass
 class meme_gen(Action):
     name: str
@@ -97,11 +125,11 @@ class find:
             # Maybe I can do self.pipe(seed) without deepcopy...
 
     @action([fileoperation._delete_all])
-    def delete(self) -> Action:
+    def delete(self):
         return dict(f_list=self._list)
 
     @action([fileoperation._rename_all])
-    def rename(self, with_suffix: str = None, with_preafix: str = None) -> Action:
+    def rename(self, with_suffix: str = None, with_preafix: str = None):
         return locals()
 
     def zip(self):
@@ -112,5 +140,5 @@ class find:
         ...
 
     @action([fileoperation._move_all])
-    def move(self, dst: str) -> Action:
+    def move(self, dst: str):
         return dict(f_list=self._list, dst=dst)
