@@ -67,10 +67,10 @@ def post_builder(name, **kwd):
 # =============================== Translate functions ===============================
 
 
-def trans_post(q: str, **kwargs) -> Result:
+def trans_post(q: str, **kwargs) -> t.Union[Result,dict]:
     trans_post = post_builder("trans")
     res = trans_post(q)
-    return res
+    return {"res":res,**kwargs}
 
 
 def trans_filter(res: Result, full=False):
